.. Djamo documentation master file, created by
   sphinx-quickstart on Sun Mar 25 22:02:09 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. sectionauthor:: Sameer Rahmani <lxsameer@gnu.org>

Welcome to Djamo's documentation!
=================================

**Djamo** is another wrapper (ORM like) package for `PyMmongo <http://api.mongodb.org/python/current/>`_ and `MongDB <http://www.mongodb.org/>`_. This documentation attempts to explain everything you need to know to use PyMongo


   :doc:`installation`
	How to install **Djamo**

   :doc:`quickstart`
	Learn Djamo basics quickly

   :doc:`api/index`
	Djamo internal API for developers

   :doc:`faq`
	Frequently asked questions

   :doc:`otherresources`
	Find more resources to learn about **MongoDB**, **PyMong** and **Djamo**


Report Bugs
-----------
You can report bugs and request features in our issue tracker in `github <https://github.com/Yellowen/Djamo/issues>`_.
If you find any mistakes in this document please report them too.

Contribute
----------
Contributions can be as simple as minor tweaks to this documentation. To contribute, fork the project on `github <https://github.com/Yellowen/Djamo>`_  and send a pull request.

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
